```@meta
EditURL = "https://codeberg.org/AdamWysokinski/NeuroAnalyzer.jl/src/branch/stable/docs/src/index.md"
```

![](assets/neuroanalyzer.png)
# NeuroAnalyzer.jl documentation

This documentation has been generated using [Documenter.jl](https://juliadocs.github.io/Documenter.jl/stable/).

## NeuroAnalyzer

```@docs
NeuroAnalyzer.na_info()
NeuroAnalyzer.na_plugins_reload()
NeuroAnalyzer.na_plugins_list()
NeuroAnalyzer.na_plugins_remove(plugin::String)
NeuroAnalyzer.na_plugins_install(plugin::String)
NeuroAnalyzer.na_plugins_update(plugin::Union{String, Nothing}=nothing)
NeuroAnalyzer.na_set_use_cuda(use_cuda::Bool)
NeuroAnalyzer.na_set_progress_bar(progress_bar::Bool)
NeuroAnalyzer.na_set_prefs(; use_cuda::Bool, progress_bar::Bool, verbose::Bool)
NeuroAnalyzer.na_set_verbose(verbose::Bool)
NeuroAnalyzer.na_version()
```

## Utils

```@docs
NeuroAnalyzer.apply(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), f::String)
NeuroAnalyzer.l1(a1::AbstractArray, a2::AbstractArray)
NeuroAnalyzer.l2(a1::AbstractArray, a2::AbstractArray)
NeuroAnalyzer.perm_cmp(a1::Array{<:Real, 3}, a2::Array{<:Real, 3}; p::Float64=0.05, perm_n::Int64=1000)
NeuroAnalyzer.component_type(obj::NeuroAnalyzer.NEURO; c::Symbol)
NeuroAnalyzer.rename_component(obj::NeuroAnalyzer.NEURO; c_old::Symbol, c_new::Symbol)
NeuroAnalyzer.rename_component!(obj::NeuroAnalyzer.NEURO; c_old::Symbol, c_new::Symbol)
NeuroAnalyzer.add_component(obj::NeuroAnalyzer.NEURO; c::Symbol, v::Any)
NeuroAnalyzer.add_component!(obj::NeuroAnalyzer.NEURO; c::Symbol, v::Any)
NeuroAnalyzer.list_component(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.extract_component(obj::NeuroAnalyzer.NEURO; c::Symbol)
NeuroAnalyzer.delete_component(obj::NeuroAnalyzer.NEURO; c::Symbol)
NeuroAnalyzer.delete_component!(obj::NeuroAnalyzer.NEURO; c::Symbol)
NeuroAnalyzer.reset_components(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.reset_components!(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.fft0(x::AbstractVector, n::Int64=0)
NeuroAnalyzer.ifft0(x::AbstractVector, n::Int64=0)
NeuroAnalyzer.fft2(x::AbstractVector)
NeuroAnalyzer.nextpow2(x::Int64)
NeuroAnalyzer.findpeaks(signal::AbstractVector; d::Int64=32)
NeuroAnalyzer.hz2rads(f::Real)
NeuroAnalyzer.rads2hz(f::Real)
NeuroAnalyzer.t2f(t::Real)
NeuroAnalyzer.f2t(f::Real)
NeuroAnalyzer.freqs(t::Union{AbstractVector, AbstractRange})
NeuroAnalyzer.freqs(s::Vector{Float64}, fs::Int64)
NeuroAnalyzer.freqs(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.generate_window(type::Symbol, n::Int64; even::Bool=false)
NeuroAnalyzer.generate_sine(f::Real, t::Union{AbstractVector, AbstractRange}, a::Real=1, p::Real=0)
NeuroAnalyzer.generate_csine(f::Real, t::Union{AbstractVector, AbstractRange}, a::Real=1)
NeuroAnalyzer.generate_sinc(t::AbstractRange=-2:0.01:2; f::Real=1, peak::Real=0, norm::Bool=true)
NeuroAnalyzer.generate_morlet(fs::Int64, f::Real, t::Real=1; ncyc::Int64=5, complex::Bool=false)
NeuroAnalyzer.generate_gaussian(fs::Int64, f::Real, t::Real=1; ncyc::Int64=5, a::Real=1.0)
NeuroAnalyzer.generate_noise(n::Int64, amp::Real=1.0; type::Symbol=:whiten)
NeuroAnalyzer.generate_morlet_fwhm(fs::Int64, f::Real, t::Real=1; h::Float64=0.25)
NeuroAnalyzer.sr(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.channel_n(obj::NeuroAnalyzer.NEURO; type::Symbol=:all)
NeuroAnalyzer.epoch_n(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.signal_len(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.epoch_len(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.signal_channels(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.get_channel_bytype(obj::NeuroAnalyzer.NEURO; type::Symbol=:all)
NeuroAnalyzer.get_channel_bywl(obj::NeuroAnalyzer.NEURO; wl::Real)
NeuroAnalyzer.history(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.labels(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.info(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.channel_cluster(obj::NeuroAnalyzer.NEURO; cluster::Symbol)
NeuroAnalyzer.band_frq(obj::NeuroAnalyzer.NEURO; band::Symbol)
NeuroAnalyzer.band_frq(fs::Int64; band::Symbol)
NeuroAnalyzer.describe(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.Base.size(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.m_pad0(m::Matrix{<:Number})
NeuroAnalyzer.m_sortperm(m::AbstractMatrix; rev::Bool=false, dims::Int64=1)
NeuroAnalyzer.m_sort(m::Matrix, m_idx::Vector{Int64}; rev::Bool=false, dims::Int64=1)
NeuroAnalyzer.m_norm(m::AbstractArray)
NeuroAnalyzer.linspace(start::Number, stop::Number, n::Int64)
NeuroAnalyzer.logspace(start::Number, stop::Number, n::Int64)
NeuroAnalyzer.cmax(x::Vector{<:Complex})
NeuroAnalyzer.cmin(x::Vector{<:Complex})
NeuroAnalyzer.tuple_order(t::Tuple{Real, Real}, rev::Bool=false)
NeuroAnalyzer.cums(signal::Array{<:Real, 3})
NeuroAnalyzer.f_nearest(m::Matrix{Tuple{Float64, Float64}}, p::Tuple{Float64, Float64})
NeuroAnalyzer.view_note(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.add_note(obj::NeuroAnalyzer.NEURO; note::String)
NeuroAnalyzer.add_note!(obj::NeuroAnalyzer.NEURO; note::String)
NeuroAnalyzer.delete_note(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.delete_note!(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.pad0(x::Union{AbstractVector, AbstractArray}, n::Int64)
NeuroAnalyzer.pad2(x::Union{AbstractVector, AbstractArray})
NeuroAnalyzer.phases(s::AbstractVector, pad::Int64=0)
NeuroAnalyzer.pick(obj::NeuroAnalyzer.NEURO; p::Union{Symbol, Vector{Symbol}})
NeuroAnalyzer.t2s(t::T, fs::Int64) where {T<:Real}
NeuroAnalyzer.s2t(s::Int64, fs::Int64)
NeuroAnalyzer.t2s(obj::NeuroAnalyzer.NEURO; t::T) where {T<:Real}
NeuroAnalyzer.s2t(obj::NeuroAnalyzer.NEURO; s::Int64)
NeuroAnalyzer.vsearch(y::T, x::AbstractVector; acc::Bool=false) where {T<:Real}
NeuroAnalyzer.vsearch(y::AbstractVector, x::AbstractVector; acc::Bool=false)
NeuroAnalyzer.vsplit(x::AbstractVector, n::Int64=1)
NeuroAnalyzer.view_header(obj::NeuroAnalyzer.NEURO)
```

## IO

```@docs
NeuroAnalyzer.export_csv(obj::NeuroAnalyzer.NEURO; file_name::String, header::Bool=false, epoch_time::Bool=false, components::Bool=false, markers::Bool=false, locs::Bool=false, history::Bool=false, overwrite::Bool=false)
NeuroAnalyzer.export_locs(obj::NeuroAnalyzer.NEURO; file_name::String, overwrite::Bool=false)
NeuroAnalyzer.export_locs(locs::DataFrame; file_name::String, overwrite::Bool=false)
NeuroAnalyzer.import_recording(file_name::String; detect_type::Bool=true, n::Int64=0)
NeuroAnalyzer.import_alice4(file_name::String; detect_type::Bool=true)
NeuroAnalyzer.import_bdf(file_name::String; detect_type::Bool=true)
NeuroAnalyzer.import_bv(file_name::String; detect_type::Bool=true)
NeuroAnalyzer.import_csv(file_name::String; detect_type::Bool=true)
NeuroAnalyzer.import_digitrack(file_name::String; detect_type::Bool=true)
NeuroAnalyzer.import_edf(file_name::String; detect_type::Bool=true)
NeuroAnalyzer.import_fiff(file_name::String; detect_type::Bool=true)
NeuroAnalyzer.import_locs(file_name::String)
NeuroAnalyzer.import_locs_ced(file_name::String)
NeuroAnalyzer.import_locs_locs(file_name::String)
NeuroAnalyzer.import_locs_elc(file_name::String)
NeuroAnalyzer.import_locs_tsv(file_name::String)
NeuroAnalyzer.import_locs_sfp(file_name::String)
NeuroAnalyzer.import_locs_csd(file_name::String)
NeuroAnalyzer.import_locs_geo(file_name::String)
NeuroAnalyzer.import_locs_mat(file_name::String)
NeuroAnalyzer.import_nirs(file_name::String)
NeuroAnalyzer.import_nirx(file_name::String)
NeuroAnalyzer.import_set(file_name::String; detect_type::Bool=true)
NeuroAnalyzer.import_snirf(file_name::String; n::Int64=0)
NeuroAnalyzer.load_locs(obj::NeuroAnalyzer.NEURO; file_name::String, maximize::Bool=true)
NeuroAnalyzer.load_locs!(obj::NeuroAnalyzer.NEURO; file_name::String, maximize::Bool=true)
NeuroAnalyzer.save(obj::NeuroAnalyzer.NEURO; file_name::String, overwrite::Bool=false)
NeuroAnalyzer.load(file_name::String)
```

## Edit

```@docs
NeuroAnalyzer.channel_type(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, String}, type::String)
NeuroAnalyzer.channel_type!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, String}, type::String)
NeuroAnalyzer.get_channel(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, String})
NeuroAnalyzer.rename_channel(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, String}, name::String)
NeuroAnalyzer.rename_channel!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, String}, name::String)
NeuroAnalyzer.edit_channel(obj::NeuroAnalyzer.NEURO; ch::Int64, field::Symbol, value::Any)
NeuroAnalyzer.edit_channel!(obj::NeuroAnalyzer.NEURO; ch::Int64, field::Symbol, value::Any)
NeuroAnalyzer.replace_channel(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, String}, s::Array{Float64, 3})
NeuroAnalyzer.replace_channel!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, String}, s::Array{Float64, 3})
NeuroAnalyzer.add_labels(obj::NeuroAnalyzer.NEURO; clabels::Vector{String})
NeuroAnalyzer.add_labels!(obj::NeuroAnalyzer.NEURO; clabels::Vector{String})
NeuroAnalyzer.delete_channel(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.delete_channel!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.keep_channel(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.keep_channel!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.keep_channel_type(obj::NeuroAnalyzer.NEURO; type::Symbol=:eeg)
NeuroAnalyzer.keep_channel_type!(obj::NeuroAnalyzer.NEURO; type::Symbol=:eeg)
NeuroAnalyzer.delete_epoch(obj::NeuroAnalyzer.NEURO; ep::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.delete_epoch!(obj::NeuroAnalyzer.NEURO; ep::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.keep_epoch(obj::NeuroAnalyzer.NEURO; ep::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.keep_epoch!(obj::NeuroAnalyzer.NEURO; ep::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.detect_bad(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), method::Vector{Symbol}=[:flat, :rmse, :rmsd, :euclid, :p2p], w::Int64=10, ftol::Float64=0.1, fr::Float64=0.3, p::Float64=0.95, tc::Float64=0.2)
NeuroAnalyzer.epoch(obj::NeuroAnalyzer.NEURO; marker::String="", offset::Real=0, ep_n::Union{Int64, Nothing}=nothing, ep_len::Union{Int64, Nothing}=nothing)
NeuroAnalyzer.epoch!(obj::NeuroAnalyzer.NEURO; marker::String="", offset::Real=0, ep_n::Union{Int64, Nothing}=nothing, ep_len::Union{Int64, Nothing}=nothing)
NeuroAnalyzer.epoch_time(obj::NeuroAnalyzer.NEURO; ts::Real)
NeuroAnalyzer.epoch_time!(obj::NeuroAnalyzer.NEURO; ts::Real)
NeuroAnalyzer.extract_channel(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, String})
NeuroAnalyzer.extract_epoch(obj::NeuroAnalyzer.NEURO; ep::Int64)
NeuroAnalyzer.extract_epoch!(obj::NeuroAnalyzer.NEURO; ep::Int64)
NeuroAnalyzer.extract_data(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), ep::Union{Int64, Vector{Int64}, <:AbstractRange}=1:epoch_n(obj), time::Bool=false, etime::Bool=false)
NeuroAnalyzer.extract_time(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.extract_eptime(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.view_marker(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.delete_marker(obj::NeuroAnalyzer.NEURO; n::Int64)
NeuroAnalyzer.delete_marker!(obj::NeuroAnalyzer.NEURO; n::Int64)
NeuroAnalyzer.add_marker(obj::NeuroAnalyzer.NEURO; id::String, start::Int64, len::Int64=1, desc::String, ch::Int64=0)
NeuroAnalyzer.add_marker!(obj::NeuroAnalyzer.NEURO; id::String, start::Int64, len::Int64=1, desc::String, ch::Int64=0)
NeuroAnalyzer.edit_marker(obj::NeuroAnalyzer.NEURO; n::Int64, id::String, start::Int64, len::Int64=1, desc::String, ch::Int64)
NeuroAnalyzer.edit_marker!(obj::NeuroAnalyzer.NEURO; n::Int64, id::String, start::Int64, len::Int64=1, desc::String, ch::Int64)
NeuroAnalyzer.reflect(obj::NeuroAnalyzer.NEURO; n::Int64=sr(obj))
NeuroAnalyzer.reflect!(obj::NeuroAnalyzer.NEURO; n::Int64=sr(obj))
NeuroAnalyzer.chop(obj::NeuroAnalyzer.NEURO; n::Int64=sr(obj))
NeuroAnalyzer.chop!(obj::NeuroAnalyzer.NEURO; n::Int64=sr(obj))
NeuroAnalyzer.trim(v::AbstractVector; seg::Tuple{Int64, Int64})
NeuroAnalyzer.trim(m::AbstractMatrix; seg::Tuple{Int64, Int64})
NeuroAnalyzer.trim(a::AbstractArray; seg::Tuple{Int64, Int64})
NeuroAnalyzer.trim(obj::NeuroAnalyzer.NEURO; seg::Tuple{Int64, Int64}, remove_epochs::Bool=true)
NeuroAnalyzer.trim!(obj::NeuroAnalyzer.NEURO; seg::Tuple{Int64, Int64}, remove_epochs::Bool=true)
NeuroAnalyzer.vch(obj::NeuroAnalyzer.NEURO; f::String)
```

## Process

```@docs
NeuroAnalyzer.add_signal(s1::AbstractVector, s2::AbstractVector)
NeuroAnalyzer.add_signal(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), s::AbstractVector)
NeuroAnalyzer.add_signal!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), s::AbstractVector)
NeuroAnalyzer.average(s::AbstractArray)
NeuroAnalyzer.average(s1::AbstractArray, s2::AbstractArray)
NeuroAnalyzer.average(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.average!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.average(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO)
NeuroAnalyzer.bpsplit(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), order::Int64=8, window::Union{Nothing, AbstractVector, Int64}=nothing)
NeuroAnalyzer.cbp(s::AbstractVector; pad::Int64=0, frq::Real, fs::Int64)
NeuroAnalyzer.cbp(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), pad::Int64=0, frq::Real)
NeuroAnalyzer.cbp!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), pad::Int64=0, frq::Real)
NeuroAnalyzer.ch_zero(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.ch_zero!(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.csd(obj::NeuroAnalyzer.NEURO; m::Int64=4, n::Int64=8, lambda::Float64=10^-5)
NeuroAnalyzer.csd!(obj::NeuroAnalyzer.NEURO; m::Int64=4, n::Int64=8, lambda::Float64=10^-5)
NeuroAnalyzer.gh(locs::DataFrame; m::Int64=4, n::Int64=8)
NeuroAnalyzer.cw_trans(s::AbstractVector; wt::T) where {T<:CWT}
NeuroAnalyzer.icw_trans(ct::AbstractArray; wt::T, type::Symbol) where {T<:CWT}
NeuroAnalyzer.cw_trans(s::AbstractArray; wt::T) where {T<:CWT}
NeuroAnalyzer.cw_trans(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), wt::T) where {T<:CWT}
NeuroAnalyzer.denoise_fft(s::AbstractVector; pad::Int64=0, t::Real=0)
NeuroAnalyzer.denoise_fft(s::AbstractArray; pad::Int64=0, t::Real=0)
NeuroAnalyzer.denoise_fft(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), pad::Int64=0, t::Int64=100)
NeuroAnalyzer.denoise_fft!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), pad::Int64=0, t::Int64=100)
NeuroAnalyzer.denoise_wavelet(s::AbstractVector; wt::T) where {T<:DiscreteWavelet}
NeuroAnalyzer.denoise_wavelet(s::AbstractArray; wt::T) where {T<:DiscreteWavelet}
NeuroAnalyzer.denoise_wavelet(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), wt::T) where {T<:DiscreteWavelet}
NeuroAnalyzer.denoise_wavelet!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), wt::T) where {T<:DiscreteWavelet}
NeuroAnalyzer.denoise_wien(s::AbstractArray)
NeuroAnalyzer.denoise_wien(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.denoise_wien!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.derivative(s::AbstractVector)
NeuroAnalyzer.derivative(s::AbstractArray)
NeuroAnalyzer.derivative(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.derivative!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.detrend(s::AbstractVector; type::Symbol=:linear, offset::Real=0, order::Int64=1, f::Float64=1.0, fs::Int64=0)
NeuroAnalyzer.detrend(s::AbstractArray; type::Symbol=:linear, offset::Real=0, order::Int64=1, f::Float64=1.0, fs::Int64=0)
NeuroAnalyzer.detrend(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), type::Symbol=:linear, offset::Real=0, order::Int64=1, f::Float64=1.0)
NeuroAnalyzer.detrend!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), type::Symbol=:linear, offset::Real=0, order::Int64=1, f::Float64=1.0)
NeuroAnalyzer.dw_trans(s::AbstractVector; wt::T, type::Symbol, l::Int64=0) where {T <: DiscreteWavelet}
NeuroAnalyzer.dw_trans(s::AbstractArray; wt::T, type::Symbol, l::Int64=0) where {T <: DiscreteWavelet}
NeuroAnalyzer.dw_trans(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), wt::T, type::Symbol, l::Int64=0) where {T <: DiscreteWavelet}
NeuroAnalyzer.idw_trans(dwt_coefs::AbstractArray; wt::T, type::Symbol) where {T <: DiscreteWavelet}
NeuroAnalyzer.dwtsplit(obj::NeuroAnalyzer.NEURO; ch::Int64, wt::T, type::Symbol, n::Int64=0) where {T<:DiscreteWavelet}
NeuroAnalyzer.erp(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.erp!(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.fconv(s::AbstractVector; kernel::Union{Vector{<:Real}, Vector{ComplexF64}}, norm::Bool=true, pad::Int64=0)
NeuroAnalyzer.fconv(s::AbstractArray; kernel::Union{Vector{<:Real}, Vector{ComplexF64}}, norm::Bool=true, pad::Int64=0)
NeuroAnalyzer.fconv(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), kernel::Union{Vector{<:Real}, Vector{ComplexF64}}, norm::Bool=true, pad::Int64=0)
NeuroAnalyzer.fconv!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), kernel::Union{Vector{<:Real}, Vector{ComplexF64}}, norm::Bool=true, pad::Int64=0)
NeuroAnalyzer.filter_create(;fprototype::Symbol, ftype::Union{Nothing, Symbol}=nothing, cutoff::Union{Real, Tuple{Real, Real}}=0, n::Int64, fs::Int64, order::Int64=8, rp::Real=-1, rs::Real=-1, bw::Real=-1, window::Union{Nothing, AbstractVector, Int64}=nothing)
NeuroAnalyzer.filter_apply(s::AbstractVector; flt::Union{Vector{Float64}, ZeroPoleGain{:z, ComplexF64, ComplexF64, Float64}, Biquad{:z, Float64}}, dir::Symbol=:twopass)
NeuroAnalyzer.filter(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), fprototype::Symbol, ftype::Union{Nothing, Symbol}=nothing, cutoff::Union{Real, Tuple{Real, Real}}=0, order::Int64=8, rp::Real=-1, rs::Real=-1, bw::Real=-1, dir::Symbol=:twopass, window::Union{Nothing, AbstractVector, Int64}=nothing, preview::Bool=false)
NeuroAnalyzer.filter!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), fprototype::Symbol, ftype::Union{Symbol, Nothing}=nothing, cutoff::Union{Real, Tuple{Real, Real}}=0, order::Int64=8, rp::Real=-1, rs::Real=-1, bw::Real=-1, dir::Symbol=:twopass, t::Real=0, window::Union{Nothing, AbstractVector, Int64}=nothing, preview::Bool=false)
NeuroAnalyzer.filter_g(s::AbstractVector; fs::Int64, pad::Int64=0, f::Real, gw::Real=5)
NeuroAnalyzer.filter_g(s::AbstractArray; fs::Int64, pad::Int64=0, f::Real, gw::Real=5)
NeuroAnalyzer.filter_g(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), pad::Int64=0, f::Real, gw::Real=5)
NeuroAnalyzer.filter_g!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), pad::Int64=0, f::Real, gw::Real=5)
NeuroAnalyzer.filter_mavg(s::AbstractVector; k::Int64=8, t::Real=0, window::AbstractVector=ones(2 * k + 1))
NeuroAnalyzer.filter_mavg(s::AbstractArray; k::Int64=8, t::Real=0, window::AbstractVector=ones(2 * k + 1))
NeuroAnalyzer.filter_mavg(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), k::Int64=8, t::Real=0, window::AbstractVector=ones(2 * k + 1))
NeuroAnalyzer.filter_mavg!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), k::Int64=8, t::Real=0, window::AbstractVector=ones(2 * k + 1))
NeuroAnalyzer.filter_mmed(s::AbstractVector; k::Int64=8, t::Real=0, window::AbstractVector=ones(2 * k + 1))
NeuroAnalyzer.filter_mmed(s::AbstractArray; k::Int64=8, t::Real=0, window::AbstractVector=ones(2 * k + 1))
NeuroAnalyzer.filter_mmed(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), k::Int64=8, t::Real=0, window::AbstractVector=ones(2 * k + 1))
NeuroAnalyzer.filter_mmed!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), k::Int64=8, t::Real=0, window::AbstractVector=ones(2 * k + 1))
NeuroAnalyzer.filter_poly(s::AbstractVector; order::Int64=8, window::Int64=10)
NeuroAnalyzer.filter_poly(s::AbstractArray; order::Int64=8, window::Int64=10)
NeuroAnalyzer.filter_poly(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), order::Int64=8, window::Int64=10)
NeuroAnalyzer.filter_poly!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), order::Int64=8, window::Int64=10)
NeuroAnalyzer.filter_sg(s::AbstractVector; order::Int64=6, window::Int64=11)
NeuroAnalyzer.filter_sg(s::AbstractArray; order::Int64=6, window::Int64=11)
NeuroAnalyzer.filter_sg(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), order::Int64=6, window::Int64=11)
NeuroAnalyzer.filter_sg!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), order::Int64=6, window::Int64=11)
NeuroAnalyzer.intensity2od(s::AbstractArray)
NeuroAnalyzer.intensity2od(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=get_channel_bytype(obj, type=:nirs_int))
NeuroAnalyzer.intensity2od!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=get_channel_bytype(obj, type=:nirs_int))
NeuroAnalyzer.invert_polarity(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.invert_polarity!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.lrinterpolate_channel(obj::NeuroAnalyzer.NEURO; ch::Int64, ep::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.lrinterpolate_channel!(obj::NeuroAnalyzer.NEURO; ch::Int64, ep::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.normalize(s::AbstractArray, n::Real=1.0; method::Symbol)
NeuroAnalyzer.normalize_zscore(s::AbstractArray)
NeuroAnalyzer.normalize_minmax(s::AbstractArray)
NeuroAnalyzer.normalize_n(s::AbstractArray, n::Real=1.0)
NeuroAnalyzer.normalize_log(s::AbstractArray)
NeuroAnalyzer.normalize_gauss(s::AbstractArray, dims::Int64=1)
NeuroAnalyzer.normalize_log10(s::AbstractArray)
NeuroAnalyzer.normalize_neglog(s::AbstractArray)
NeuroAnalyzer.normalize_neglog10(s::AbstractArray)
NeuroAnalyzer.normalize_neg(s::AbstractArray)
NeuroAnalyzer.normalize_pos(s::AbstractArray)
NeuroAnalyzer.normalize_perc(s::AbstractArray)
NeuroAnalyzer.normalize_invroot(s::AbstractArray)
NeuroAnalyzer.normalize(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), method::Symbol)
NeuroAnalyzer.normalize!(obj::NeuroAnalyzer.NEURO; channel::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), method::Symbol)
NeuroAnalyzer.od2conc(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=get_channel_bytype(obj, type=:nirs_od), ppf::Vector{<:Real}=ones(length(obj.header.recording[:wavelengths])))
NeuroAnalyzer.od2conc!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=get_channel_bytype(obj, type=:nirs_od), ppf::Vector{<:Real}=ones(length(obj.header.recording[:wavelengths])))
NeuroAnalyzer.plinterpolate_channel(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}, ep::Union{Int64, Vector{Int64}, <:AbstractRange}, imethod::Symbol=:sh, interpolation_factor::Int64=100)
NeuroAnalyzer.plinterpolate_channel!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}}, ep::Union{Int64, Vector{Int64}, <:AbstractRange}, imethod::Symbol=:shepard, interpolation_factor::Int64=100)
NeuroAnalyzer.reference_ce(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}, med::Bool=false)
NeuroAnalyzer.reference_ce!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}, med::Bool=false)
NeuroAnalyzer.reference_avg(obj::NeuroAnalyzer.NEURO; exclude_fpo::Bool=false, exclude_current::Bool=true, med::Bool=false)
NeuroAnalyzer.reference_avg!(obj::NeuroAnalyzer.NEURO; exclude_fpo::Bool=false, exclude_current::Bool=true, med::Bool=false)
NeuroAnalyzer.reference_a(obj::NeuroAnalyzer.NEURO; type::Symbol=:l, med::Bool=false)
NeuroAnalyzer.reference_a!(obj::NeuroAnalyzer.NEURO; type::Symbol=:l, med::Bool=false)
NeuroAnalyzer.reference_m(obj::NeuroAnalyzer.NEURO; type::Symbol=:l, med::Bool=false)
NeuroAnalyzer.reference_m!(obj::NeuroAnalyzer.NEURO; type::Symbol=:l, med::Bool=false)
NeuroAnalyzer.reference_plap(obj::NeuroAnalyzer.NEURO; nn::Int64=4, weights::Bool=false, med::Bool=false)
NeuroAnalyzer.reference_plap!(obj::NeuroAnalyzer.NEURO; nn::Int64=4, weights::Bool=false, med::Bool=false)
NeuroAnalyzer.remove_dc(s::AbstractVector)
NeuroAnalyzer.remove_dc(s::AbstractArray)
NeuroAnalyzer.remove_dc(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.remove_dc!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.resample(s::AbstractVector; old_sr::Int64, new_sr::Int64)
NeuroAnalyzer.resample(s::AbstractArray; old_sr::Int64, new_sr::Int64)
NeuroAnalyzer.resample(obj::NeuroAnalyzer.NEURO; new_sr::Int64)
NeuroAnalyzer.resample!(obj::NeuroAnalyzer.NEURO; new_sr::Int64)
NeuroAnalyzer.upsample(obj::NeuroAnalyzer.NEURO; new_sr::Int64)
NeuroAnalyzer.upsample!(obj::NeuroAnalyzer.NEURO; new_sr::Int64)
NeuroAnalyzer.downsample(obj::NeuroAnalyzer.NEURO; new_sr::Int64)
NeuroAnalyzer.downsample!(obj::NeuroAnalyzer.NEURO; new_sr::Int64)
NeuroAnalyzer.scale(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), factor::Real)
NeuroAnalyzer.scale!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), factor::Real)
NeuroAnalyzer.standardize(s::AbstractArray)
NeuroAnalyzer.standardize(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj))
NeuroAnalyzer.standardize!(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.taper(signal::AbstractVector; t::Union{AbstractVector, Vector{ComplexF64}})
NeuroAnalyzer.taper(s::AbstractArray; t::Union{Vector{<:Real}, Vector{ComplexF64}})
NeuroAnalyzer.taper(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), t::Union{Vector{<:Real}, Vector{ComplexF64}})
NeuroAnalyzer.taper!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), taper::Union{Vector{<:Real}, Vector{ComplexF64}})
NeuroAnalyzer.tconv(s::AbstractVector; kernel::AbstractVector)
NeuroAnalyzer.tconv(s::AbstractArray; kernel::Union{Vector{<:Real}, Vector{ComplexF64}})
NeuroAnalyzer.tconv(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), kernel::Union{Vector{<:Real}, Vector{ComplexF64}})
NeuroAnalyzer.wbp(s::AbstractVector; pad::Int64=0, frq::Real, fs::Int64, ncyc::Int64=6)
NeuroAnalyzer.wbp(s::AbstractArray; pad::Int64=0, frq::Real, fs::Int64, ncyc::Int64=6)
NeuroAnalyzer.wbp(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), pad::Int64=0, frq::Real, ncyc::Int64=6)
NeuroAnalyzer.wbp!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), pad::Int64=0, frq::Real, ncyc::Int64=6)
```

## Locs

```@docs
NeuroAnalyzer.add_locs(obj::NeuroAnalyzer.NEURO; locs::DataFrame)
NeuroAnalyzer.add_locs!(obj::NeuroAnalyzer.NEURO; locs::DataFrame)
NeuroAnalyzer.cart2pol(x::Real, y::Real)
NeuroAnalyzer.pol2cart(radius::Real, theta::Real)
NeuroAnalyzer.sph2cart(radius::Real, theta::Real, phi::Real)
NeuroAnalyzer.cart2sph(x::Real, y::Real, z::Real)
NeuroAnalyzer.sph2pol(radius::Real, theta::Real, phi::Real)
NeuroAnalyzer.locs_sph2cart(locs::DataFrame)
NeuroAnalyzer.locs_sph2cart!(locs::DataFrame)
NeuroAnalyzer.locs_cart2sph(locs::DataFrame)
NeuroAnalyzer.locs_cart2sph!(locs::DataFrame)
NeuroAnalyzer.locs_cart2pol(locs::DataFrame)
NeuroAnalyzer.locs_cart2pol!(locs::DataFrame)
NeuroAnalyzer.locs_sph2pol(locs::DataFrame)
NeuroAnalyzer.locs_sph2pol!(locs::DataFrame)
NeuroAnalyzer.locs_details(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, String}, out::Bool=true)
NeuroAnalyzer.edit_locs(obj::NeuroAnalyzer.NEURO; ch::Union{String, Int64}, x::Union{Real, Nothing}=nothing, y::Union{Real, Nothing}=nothing, z::Union{Real, Nothing}=nothing, theta::Union{Real, Nothing}=nothing, radius::Union{Real, Nothing}=nothing, theta_sph::Union{Real, Nothing}=nothing, radius_sph::Union{Real, Nothing}=nothing, phi_sph::Union{Real, Nothing}=nothing, name::String="", type::String="")
NeuroAnalyzer.edit_locs!(obj::NeuroAnalyzer.NEURO; ch::Union{String, Int64}, x::Union{Real, Nothing}=nothing, y::Union{Real, Nothing}=nothing, z::Union{Real, Nothing}=nothing, theta::Union{Real, Nothing}=nothing, radius::Union{Real, Nothing}=nothing, theta_sph::Union{Real, Nothing}=nothing, radius_sph::Union{Real, Nothing}=nothing, phi_sph::Union{Real, Nothing}=nothing, name::String="", type::String="")
NeuroAnalyzer.locs_flipy(locs::DataFrame; polar::Bool=true, spherical::Bool=true)
NeuroAnalyzer.locs_flipy!(locs::DataFrame; polar::Bool=true, spherical::Bool=true)
NeuroAnalyzer.locs_flipx(locs::DataFrame; polar::Bool=true, spherical::Bool=true)
NeuroAnalyzer.locs_flipx!(locs::DataFrame; polar::Bool=true, spherical::Bool=true)
NeuroAnalyzer.locs_flipz(locs::DataFrame)
NeuroAnalyzer.locs_flipz!(locs::DataFrame)
NeuroAnalyzer.locs_rotx(locs::DataFrame; a::Real, polar::Bool=true, spherical::Bool=true)
NeuroAnalyzer.locs_rotx!(locs::DataFrame; a::Real, polar::Bool=true, spherical::Bool=true)
NeuroAnalyzer.locs_scale(locs::DataFrame; r::Real, polar::Bool=true, spherical::Bool=true)
NeuroAnalyzer.locs_scale!(locs::DataFrame; r::Real, polar::Bool=true, spherical::Bool=true)
NeuroAnalyzer.locs_normalize(locs::DataFrame; polar::Bool=true, spherical::Bool=false)
NeuroAnalyzer.locs_normalize!(locs::DataFrame; polar::Bool=true, spherical::Bool=false)
NeuroAnalyzer.locs_swapxy(locs::DataFrame; polar::Bool=true, spherical::Bool=true)
NeuroAnalyzer.locs_swapxy!(locs::DataFrame; polar::Bool=true, spherical::Bool=true)
```

## Analyze

```@docs
NeuroAnalyzer.acov(s::AbstractVector; lag::Int64=1, norm::Bool=false)
NeuroAnalyzer.acov(s::AbstractArray; lag::Int64=1, norm::Bool=false)
NeuroAnalyzer.acov(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), lag::Int64=1, norm::Bool=false)
NeuroAnalyzer.ampdiff(s::AbstractArray; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=size(s, 1))
NeuroAnalyzer.ampdiff(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj))
NeuroAnalyzer.band_mpower(s::AbstractVector; fs::Int64, f::Tuple{Real, Real}, mt::Bool=false)
NeuroAnalyzer.band_mpower(s::AbstractArray; fs::Int64, f::Tuple{Real, Real}, mt::Bool=false)
NeuroAnalyzer.band_mpower(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), f::Tuple{Real, Real}, mt::Bool=false)
NeuroAnalyzer.band_power(s::AbstractVector; fs::Int64, f::Tuple{Real, Real}, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.band_power(s::AbstractArray; fs::Int64, f::Tuple{Real, Real}, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.band_power(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), f::Tuple{Real, Real}, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.corm(s::AbstractVector; norm::Bool=false)
NeuroAnalyzer.corm(s1::AbstractVector, s2::AbstractVector; norm::Bool=false)
NeuroAnalyzer.corm(s::AbstractArray; norm::Bool=false)
NeuroAnalyzer.corm(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), norm::Bool=false)
NeuroAnalyzer.covm(s::AbstractVector; norm::Bool=false)
NeuroAnalyzer.covm(s1::AbstractVector, s2::AbstractVector; norm::Bool=false)
NeuroAnalyzer.covm(s::AbstractArray; norm::Bool=false)
NeuroAnalyzer.covm(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), norm::Bool=false)
NeuroAnalyzer.cps(s1::AbstractVector, s2::AbstractVector; fs::Int64)
NeuroAnalyzer.cps(s::AbstractArray; fs::Int64)
NeuroAnalyzer.cps(s1::AbstractArray, s2::AbstractArray; fs::Int64)
NeuroAnalyzer.cps(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj))
NeuroAnalyzer.cps(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj2), ep1::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj2)))
NeuroAnalyzer.gfp(s::AbstractVector)
NeuroAnalyzer.gfp_norm(s::AbstractVector)
NeuroAnalyzer.diss(s1::AbstractVector, s2::AbstractVector)
NeuroAnalyzer.diss(s::AbstractArray)
NeuroAnalyzer.diss(s1::AbstractArray, s2::AbstractArray)
NeuroAnalyzer.diss(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj))
NeuroAnalyzer.diss(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj2), ep1::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj2)), norm::Bool=true)
NeuroAnalyzer.entropy(s::AbstractVector)
NeuroAnalyzer.entropy(s::AbstractArray)
NeuroAnalyzer.entropy(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj))
NeuroAnalyzer.negentropy(signal::AbstractVector)
NeuroAnalyzer.negentropy(s::AbstractArray)
NeuroAnalyzer.negentropy(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj))
NeuroAnalyzer.tenv(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), d::Int64=32)
NeuroAnalyzer.tenv_mean(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), dims::Int64, d::Int64=32)
NeuroAnalyzer.tenv_median(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), dims::Int64, d::Int64=32)
NeuroAnalyzer.penv(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), d::Int64=8, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.penv_mean(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), dims::Int64, d::Int64=8, mt::Bool=false)
NeuroAnalyzer.penv_median(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), dims::Int64, d::Int64=8, mt::Bool=false)
NeuroAnalyzer.senv(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), d::Int64=2, mt::Bool=false, t::Union{Real, Nothing}=nothing)
NeuroAnalyzer.senv_mean(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), dims::Int64, d::Int64=2, mt::Bool=false, t::Union{Real, Nothing}=nothing)
NeuroAnalyzer.senv_median(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), dims::Int64, d::Int64=2, mt::Bool=false, t::Union{Real, Nothing}=nothing)
NeuroAnalyzer.henv(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), d::Int64=32)
NeuroAnalyzer.henv_mean(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), dims::Int64, d::Int64=32)
NeuroAnalyzer.henv_median(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), dims::Int64, d::Int64=32)
NeuroAnalyzer.env_cor(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; type::Symbol=:amp, ch1::Int64, ch2::Int64, ep1::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj2)))
NeuroAnalyzer.erp_peaks(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.fcoherence(s::AbstractMatrix; fs::Int64, frq_lim::Union{Tuple{Real, Real}, Nothing}=nothing)
NeuroAnalyzer.fcoherence(s1::AbstractMatrix, s2::AbstractMatrix; fs::Int64, frq_lim::Union{Tuple{Real, Real}, Nothing}=nothing)
NeuroAnalyzer.fcoherence(s1::AbstractArray, s2::AbstractArray; fs::Int64, frq_lim::Union{Tuple{Real, Real}, Nothing}=nothing)
NeuroAnalyzer.fcoherence(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, <:AbstractRange}=0, ch2::Union{Int64, Vector{Int64}, <:AbstractRange}=0, ep1::Union{Int64, Vector{Int64}, <:AbstractRange}=0, ep2::Union{Int64, Vector{Int64}, <:AbstractRange}=0, frq_lim::Union{Tuple{Real, Real}, Nothing}=nothing)
NeuroAnalyzer.frqinst(s::AbstractVector; fs::Int64)
NeuroAnalyzer.frqinst(s::AbstractArray; fs::Int64)
NeuroAnalyzer.frqinst(obj::NeuroAnalyzer.NEURO; channel::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj))
NeuroAnalyzer.ged(s1::AbstractArray, s2::AbstractArray)
NeuroAnalyzer.ged(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj2), ep1::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj2)))
NeuroAnalyzer.ica(s::AbstractMatrix; n::Int64, tol::Float64=1.0e-6, iter::Int64=100, f::Symbol=:tanh)
NeuroAnalyzer.ica(s::AbstractArray; n::Int64, tol::Float64=1.0e-6, iter::Int64=100, f::Symbol=:tanh)
NeuroAnalyzer.ica_reconstruct(s::AbstractArray; ic::AbstractArray, ic_mw::AbstractArray, ic_idx::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.ica(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), n::Int64, tol::Float64=1.0e-6, iter::Int64=100, f::Symbol=:tanh)
NeuroAnalyzer.ica_reconstruct(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), ic_idx::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.ica_reconstruct!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), ic_idx::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.ica_reconstruct(obj::NeuroAnalyzer.NEURO, ic::Array{Float64, 3}, ic_mw::Array{Float64, 3}; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), ic_idx::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.ica_reconstruct!(obj::NeuroAnalyzer.NEURO, ic::Array{Float64, 3}, ic_mw::Array{Float64, 3}; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), ic_idx::Union{Int64, Vector{Int64}, <:AbstractRange})
NeuroAnalyzer.ispc(s1::AbstractVector, s2::AbstractVector)
NeuroAnalyzer.ispc(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj))
NeuroAnalyzer.ispc(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj2), ep1::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj2)))
NeuroAnalyzer.itpc(s::AbstractArray; t::Int64, w::Union{AbstractVector, Nothing}=nothing)
NeuroAnalyzer.itpc(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), t::Int64, w::Union{Vector{<:Real}, Nothing}=nothing)
NeuroAnalyzer.itpc_spec(obj::NeuroAnalyzer.NEURO; ch::Int64, frq_lim::Tuple{Real, Real}=(0, sr(obj) ÷ 2), frq_n::Int64=_tlength(frq_lim), frq::Symbol=:log, w::Union{Vector{<:Real}, Nothing}=nothing)
NeuroAnalyzer.mdiff(s1::AbstractMatrix, s2::AbstractMatrix; n::Int64=3, method::Symbol=:absdiff)
NeuroAnalyzer.mdiff(s1::AbstractArray, s2::AbstractArray; n::Int64=3, method::Symbol=:absdiff)
NeuroAnalyzer.mdiff(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), n::Int64=3, method::Symbol=:absdiff)
NeuroAnalyzer.mdiff(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; channel1::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj1), channel2::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj2), epoch1::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj1)), epoch2::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj2)), n::Int64=3, method::Symbol=:absdiff)
NeuroAnalyzer.mutual_information(s1::AbstractVector, s2::AbstractVector)
NeuroAnalyzer.mutual_information(s1::AbstractArray, s2::AbstractArray)
NeuroAnalyzer.mutual_information(s::AbstractArray)
NeuroAnalyzer.mutual_information(obj::NeuroAnalyzer.NEURO; channel::Union{Vector{Int64}, AbstractRange}=signal_channels(obj))
NeuroAnalyzer.mutual_information(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj2), ep1::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj2)))
NeuroAnalyzer.msci95(s::AbstractVector)
NeuroAnalyzer.msci95(s::AbstractMatrix; n::Int64=3, method::Symbol=:normal)
NeuroAnalyzer.msci95(s::AbstractArray; n::Int64=3, method::Symbol=:normal)
NeuroAnalyzer.msci95(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), n::Int64=3, method::Symbol=:normal)
NeuroAnalyzer.msci95(s1::AbstractVector, s2::AbstractVector)
NeuroAnalyzer.msci95(s1::AbstractArray, s2::AbstractArray; n::Int64=3, method::Symbol=:normal)
NeuroAnalyzer.msci95(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, <:AbstractRange}=get_channel_bytype(obj1, type=Symbol(obj2.header.recording[:data_type])), ep1::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj2)))
NeuroAnalyzer.pca(s::AbstractArray; n::Int64)
NeuroAnalyzer.pca(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), n::Int64)
NeuroAnalyzer.pca_reconstruct(s::AbstractArray; pc::AbstractArray, pc_model::MultivariateStats.PCA{Float64})
NeuroAnalyzer.pca_reconstruct(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.pca_reconstruct!(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.pca_reconstruct(obj::NeuroAnalyzer.NEURO, pc::Array{Float64, 3}, pc_model::MultivariateStats.PCA{Float64}; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.pca_reconstruct!(obj::NeuroAnalyzer.NEURO, pc::Array{Float64, 3}, pc_model::MultivariateStats.PCA{Float64}; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)))
NeuroAnalyzer.phdiff(s1::AbstractVector, s2::AbstractVector; pad::Int64=0, h::Bool=false)
NeuroAnalyzer.phdiff(s::AbstractArray; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=1:size(s, 1), avg::Symbol=:phase, pad::Int64=0, h::Bool=false)
NeuroAnalyzer.phdiff(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), avg::Symbol=:phase, pad::Int64=0, h::Bool=false)
NeuroAnalyzer.pli(s1::AbstractVector, s2::AbstractVector)
NeuroAnalyzer.pli(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj2), ep1::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj2)))
NeuroAnalyzer.pli(obj::NeuroAnalyzer.NEURO; channel::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj))
NeuroAnalyzer.psd(s::Vector{Float64}; fs::Int64, norm::Bool=false, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.psd(s::AbstractMatrix; fs::Int64, norm::Bool=false, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.psd(s::AbstractArray; fs::Int64, norm::Bool=false, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.psd(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), norm::Bool=false, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.mwpsd(s::AbstractVector; pad::Int64=0, norm::Bool=true, fs::Int64, frq_lim::Tuple{Real, Real}=(0, fs ÷ 2), frq_n::Int64=_tlength(frq_lim), frq::Symbol=:lin, ncyc::Union{Int64, Tuple{Int64, Int64}}=32)
NeuroAnalyzer.mwpsd(s::AbstractMatrix; pad::Int64=0, norm::Bool=true, fs::Int64, frq_lim::Tuple{Real, Real}=(0, fs ÷ 2), frq_n::Int64=_tlength(frq_lim), frq::Symbol=:lin, ncyc::Union{Int64, Tuple{Int64, Int64}}=32)
NeuroAnalyzer.mwpsd(s::AbstractArray; pad::Int64=0, norm::Bool=true, fs::Int64, frq_lim::Tuple{Real, Real}=(0, fs ÷ 2), frq_n::Int64=_tlength(frq_lim), frq::Symbol=:lin, ncyc::Union{Int64, Tuple{Int64, Int64}}=32)
NeuroAnalyzer.mwpsd(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), pad::Int64=0, norm::Bool=true, frq_lim::Tuple{Real, Real}=(0, sr(obj) ÷ 2), frq_n::Int64=_tlength(frq_lim), frq::Symbol=:lin, ncyc::Union{Int64, Tuple{Int64, Int64}}=32)
NeuroAnalyzer.psd_rel(s::AbstractVector; fs::Int64, norm::Bool=false, mt::Bool=false, nt::Int64=7, f::Union{Tuple{Real, Real}, Nothing}=nothing)
NeuroAnalyzer.psd_rel(s::AbstractMatrix; fs::Int64, norm::Bool=false, mt::Bool=false, nt::Int64=7, f::Union{Tuple{Real, Real}, Nothing}=nothing)
NeuroAnalyzer.psd_rel(s::AbstractArray; fs::Int64, norm::Bool=false, mt::Bool=false, nt::Int64=7, f::Union{Tuple{Real, Real}, Nothing}=nothing)
NeuroAnalyzer.psd_rel(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), norm::Bool=false, mt::Bool=false, nt::Int64=7, f::Union{Tuple{Real, Real}, Nothing}=nothing)
NeuroAnalyzer.psd_slope(s::AbstractVector; fs::Int64, f::Tuple{Real, Real}=(0, fs ÷ 2), norm::Bool=false, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.psd_slope(s::AbstractArray; fs::Int64, f::Tuple{Real, Real}=(0, fs ÷ 2), norm::Bool=false, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.psd_slope(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), f::Tuple{Real, Real}=(0, sr(obj) ÷ 2), norm::Bool=false, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.rms(s::AbstractVector)
NeuroAnalyzer.rms(s::AbstractArray)
NeuroAnalyzer.rms(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj))
NeuroAnalyzer.rmse(s1::AbstractVector, s2::AbstractVector)
NeuroAnalyzer.rmse(s1::AbstractArray, s2::AbstractArray)
NeuroAnalyzer.rmse(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj2), ep1::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj2)))
NeuroAnalyzer.snr(s::AbstractVector)
NeuroAnalyzer.snr2(s::AbstractVector)
NeuroAnalyzer.snr(s::AbstractArray; t::Vector{Float64}, type::Symbol=:rms)
NeuroAnalyzer.snr(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), type::Symbol=:rms)
NeuroAnalyzer.spec_seg(sp::Matrix{Float64}, st::Vector{Float64}, sf::Vector{Float64}; t::Tuple{Real, Real}, f::Tuple{Real, Real})
NeuroAnalyzer.spec_seg(sp::AbstractArray, st::AbstractVector, sf::AbstractVector; ch::Int64, t::Tuple{Real, Real}, f::Tuple{Real, Real})
NeuroAnalyzer.spectrogram(s::AbstractVector; fs::Int64, norm::Bool=true, mt::Bool=false, st::Bool=false)
NeuroAnalyzer.mwspectrogram(s::AbstractVector; pad::Int64=0, norm::Bool=true, fs::Int64, frq_lim::Tuple{Real, Real}=(0, fs ÷ 2), frq_n::Int64=_tlength(frq_lim), frq::Symbol=:lin, ncyc::Union{Int64, Tuple{Int64, Int64}}=32)
NeuroAnalyzer.ghspectrogram(s::AbstractVector; fs::Int64, norm::Bool=true, frq_lim::Tuple{Real, Real}=(0, fs ÷ 2), frq_n::Int64=_tlength(frq_lim), frq::Symbol=:lin, gw::Real=5)
NeuroAnalyzer.cwtspectrogram(s::AbstractVector; wt::T, fs::Int64, norm::Bool=true, frq_lim::Tuple{Real, Real}=(0, fs ÷ 2)) where {T <: CWT}
NeuroAnalyzer.spectrogram(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), pad::Int64=0, frq_lim::Tuple{Real, Real}=(0, sr(obj) ÷ 2), frq_n::Int64=_tlength(frq_lim), method::Symbol=:standard, norm::Bool=true, frq::Symbol=:log, gw::Real=5, ncyc::Union{Int64, Tuple{Int64, Int64}}=32, wt::T=wavelet(Morlet(2π), β=32, Q=128)) where {T <: CWT}
NeuroAnalyzer.spectrum(s::AbstractVector; pad::Int64=0, norm::Bool=false)
NeuroAnalyzer.hspectrum(s::AbstractVector; pad::Int64=0, norm::Bool=true)
NeuroAnalyzer.hspectrum(s::AbstractArray; pad::Int64=0, norm::Bool=true)
NeuroAnalyzer.spectrum(s::AbstractArray; pad::Int64=0, h::Bool=false, norm::Bool=false)
NeuroAnalyzer.spectrum(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), pad::Int64=0, h::Bool=false, norm::Bool=false)
NeuroAnalyzer.stationarity_hilbert(s::AbstractVector)
NeuroAnalyzer.stationarity_mean(s::AbstractVector; window::Int64)
NeuroAnalyzer.stationarity_var(s::AbstractVector; window::Int64)
NeuroAnalyzer.stationarity(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, AbstractRange}=signal_channels(obj), window::Int64=10, method::Symbol=:hilbert)
NeuroAnalyzer.epoch_stats(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.channel_stats(obj::NeuroAnalyzer.NEURO)
NeuroAnalyzer.tcoherence(s1::AbstractVector, s2::AbstractVector; pad::Int64=0)
NeuroAnalyzer.tcoherence(s1::AbstractArray, s2::AbstractArray; pad::Int64=0)
NeuroAnalyzer.tcoherence(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, AbstractRange}=signal_channels(obj2), ep1::Union{Int64, Vector{Int64}, AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, AbstractRange}=_c(epoch_n(obj2)), pad::Int64=0)
NeuroAnalyzer.tkeo(s::AbstractVector)
NeuroAnalyzer.tkeo(s::AbstractArray)
NeuroAnalyzer.tkeo(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, AbstractRange}=signal_channels(obj))
NeuroAnalyzer.total_power(s::AbstractVector; fs::Int64, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.total_power(s::AbstractArray; fs::Int64, mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.total_power(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, AbstractRange}=signal_channels(obj), mt::Bool=false, nt::Int64=7)
NeuroAnalyzer.vartest(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, AbstractRange}=signal_channels(obj))
NeuroAnalyzer.vartest(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, AbstractRange}=signal_channels(obj2), ep1::Union{Int64, Vector{Int64}, AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, AbstractRange}=_c(epoch_n(obj2)))
NeuroAnalyzer.xcorr(s1::AbstractVector, s2::AbstractVector)
NeuroAnalyzer.xcorr(s1::AbstractArray, s2::AbstractArray)
NeuroAnalyzer.xcorr(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj2), ep1::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(epoch_n(obj2)))
NeuroAnalyzer.xcorr(s::AbstractArray)
NeuroAnalyzer.xcorr(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), lag::Int64=1, norm::Bool=false)
NeuroAnalyzer.xcov(s1::AbstractVector, s2::AbstractVector; lag::Int64=1, norm::Bool=false)
NeuroAnalyzer.xcov(s1::AbstractArray, s2::AbstractArray; lag::Int64=1, norm::Bool=false)
NeuroAnalyzer.xcov(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, AbstractRange}=signal_channels(obj), lag::Int64=1, norm::Bool=false)
NeuroAnalyzer.xcov(obj1::NeuroAnalyzer.NEURO, obj2::NeuroAnalyzer.NEURO; ch1::Union{Int64, Vector{Int64}, AbstractRange}=signal_channels(obj1), ch2::Union{Int64, Vector{Int64}, AbstractRange}=signal_channels(obj2), ep1::Union{Int64, Vector{Int64}, AbstractRange}=_c(epoch_n(obj1)), ep2::Union{Int64, Vector{Int64}, AbstractRange}=_c(epoch_n(obj2)), lag::Int64=1, norm::Bool=false)
```

## Plot

```@docs
NeuroAnalyzer.plot_compose(p::Vector{Plots.Plot{Plots.GRBackend}}; layout::Union{Matrix{Any}, Tuple{Int64, Int64}, Plots.GridLayout}, mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_empty()
NeuroAnalyzer.plot_connections(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), connections::Matrix{<:Real}, threshold::Real, threshold_type::Symbol=:g, weights::Bool=true, channel_labels::Bool=true, head_labels::Bool=false, mono::Bool=false, head_details::Bool=true, plot_size::Int64=800, title::String="", kwargs...)
NeuroAnalyzer.plot_connections(locs::DataFrame; ch::Union{Vector{Int64}, AbstractRange}, connections::Matrix{<:Real}, threshold::Real, threshold_type::Symbol=:g, weights::Bool=true, channel_labels::Bool=true, head_labels::Bool=false, mono::Bool=false, head_details::Bool=true, plot_size::Int64=800, kwargs...)
NeuroAnalyzer.plot_dipole2d(d::NeuroAnalyzer.DIPOLE)
NeuroAnalyzer.plot_dipole3d(d::NeuroAnalyzer.DIPOLE; project::Bool=true)
NeuroAnalyzer.plot_erp(t::Union{AbstractVector, AbstractRange}, s::AbstractVector; xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, yrev::Bool=false, kwargs...)
NeuroAnalyzer.plot_erp_avg(t::Union{AbstractVector, AbstractRange}, s::AbstractArray; xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, yrev::Bool=false, kwargs...)
NeuroAnalyzer.plot_erp_butterfly(t::Union{AbstractVector, AbstractRange}, s::AbstractArray; clabels::Vector{String}=[""], xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, avg::Bool=true, yrev::Bool=false, kwargs...)
NeuroAnalyzer.plot_erp_topo(locs::DataFrame, t::Vector{Float64}, s::Array{Float64, 2}; channel=Union{Vector{Int64}, AbstractRange}, clabels::Vector{String}=[""], xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, yrev::Bool=false, kwargs...)
NeuroAnalyzer.plot_erp(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}, tm::Union{Int64, Vector{Int64}}=0, xlabel::String="default", ylabel::String="default", title::String="default", cb::Bool=true, cb_title::String="default", mono::Bool=false, peaks::Bool=true, channel_labels::Bool=true, type::Symbol=:normal, yrev::Bool=false, kwargs...)
NeuroAnalyzer.plot_erp_stack(t::AbstractVector, s::AbstractArray; clabels::Vector{String}=[""], xlabel::String="", ylabel::String="", title::String="", cb::Bool=true, cb_title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_erp(obj::NeuroAnalyzer.NEURO, c::Union{Symbol, AbstractArray}; c_idx::Union{Int64, Vector{Int64}, <:AbstractRange}=0, tm::Union{Int64, Vector{Int64}}=0, xlabel::String="default", ylabel::String="default", title::String="default", cb::Bool=true, cb_title::String="default", mono::Bool=false, peaks::Bool=true, channel_labels::Bool=true, type::Symbol=:normal, yrev::Bool=false, units::String="", kwargs...)
NeuroAnalyzer.plot_filter_response(; fs::Int64, n::Int64=2560, fprototype::Symbol, ftype::Union{Symbol, Nothing}=nothing, cutoff::Union{Real, Tuple}, order::Int64=8, rp::Real=8, rs::Real=-1, bw::Real=-1, window::Union{Vector{Float64}, Nothing}=nothing, mono::Bool=false, frq_lim::Tuple{Real, Real}=(0, fs / 2), kwargs...)
NeuroAnalyzer.plot_locs(locs::DataFrame; ch::Union{Int64, Vector{Int64}, <:AbstractRange}, selected::Union{Int64, Vector{Int64}, <:AbstractRange}=0, channel_labels::Bool=true, head::Bool=true, head_labels::Bool=true, mono::Bool=false, head_details::Bool=true, grid::Bool=false, plot_size::Int64=400)
NeuroAnalyzer.plot_locs3d(locs::DataFrame; ch::Union{Int64, Vector{Int64}, <:AbstractRange}, selected::Union{Int64, Vector{Int64}, <:AbstractRange}=0, channel_labels::Bool=true, head_labels::Bool=true, mono::Bool=false, plot_size::Int64=800)
NeuroAnalyzer.plot_locs(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), selected::Union{Int64, Vector{Int64}, <:AbstractRange}=0, channel_labels::Bool=true, src_labels::Bool=false, det_labels::Bool=false, opt_labels::Bool=false, head::Bool=true, head_labels::Bool=false, plot_size::Int64=400, head_details::Bool=true, mono::Bool=false, threed::Bool=false, grid::Bool=false, kwargs...)
NeuroAnalyzer.plot_locs_nirs(locs::DataFrame, opt_pairs::Matrix{Int64}, src_n::Int64, det_n::Int64; src_labels::Bool=false, det_labels::Bool=false, opt_labels::Bool=false, ch::Union{Int64, Vector{Int64}, <:AbstractRange}=1, selected::Union{Int64, Vector{Int64}, <:AbstractRange}=0, head::Bool=true, head_labels::Bool=true, mono::Bool=false, head_details::Bool=true, grid::Bool=false, plot_size::Int64=400)
NeuroAnalyzer.plot_psd(sf::Vector{Float64}, sp::Vector{Float64}; norm::Bool=true, frq_lim::Tuple{Real, Real}=(sf[1], sf[end]), xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, ax::Symbol=:linlin, kwargs...)
NeuroAnalyzer.plot_psd(sf::Vector{Float64}, sp::Matrix{Float64}; clabels::Vector{String}=[""], norm::Bool=true, frq_lim::Tuple{Real, Real}=(sf[1], sf[end]), xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, ax::Symbol=:linlin, kwargs...)
NeuroAnalyzer.plot_psd_avg(sf::Vector{Float64}, sp::Array{Float64, 2}; norm::Bool=true, frq_lim::Tuple{Real, Real}=(sf[1], sf[end]), xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, ax::Symbol=:linlin, kwargs...)
NeuroAnalyzer.plot_psd_butterfly(sf::Vector{Float64}, sp::Array{Float64, 2}; clabels::Vector{String}=[""], norm::Bool=true, frq_lim::Tuple{Real, Real}=(sf[1], sf[end]), xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, ax::Symbol=:linlin, kwargs...)
NeuroAnalyzer.plot_psd_3d(sf::Vector{Float64}, sp::Array{Float64, 2}; clabels::Vector{String}=[""], norm::Bool=true, frq_lim::Tuple{Real, Real}=(sf[1], sf[end]), xlabel::String="", ylabel::String="", zlabel::String="", title::String="", mono::Bool=false, ax::Symbol=:linlin, variant::Symbol, kwargs...)
NeuroAnalyzer.plot_psd_topo(locs::DataFrame, sf::Vector{Float64}, sp::Array{Float64, 2}; ch=Union{Vector{Int64}, AbstractRange}, clabels::Vector{String}=[""], norm::Bool=true, frq_lim::Tuple{Real, Real}=(sf[1], sf[end]), xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, ax::Symbol=:linlin, kwargs...)
NeuroAnalyzer.plot_psd(obj::NeuroAnalyzer.NEURO; ep::Int64=1, ch::Union{Int64, Vector{Int64}, <:AbstractRange}, norm::Bool=true, method::Symbol=:welch, nt::Int64=7, frq_lim::Tuple{Real, Real}=(0, sr(obj) ÷ 2), ncyc::Union{Int64, Tuple{Int64, Int64}}=32, ref::Symbol=:abs, ax::Symbol=:linlin, xlabel::String="default", ylabel::String="default", zlabel::String="default", title::String="default", mono::Bool=false, type::Symbol=:normal, kwargs...)
NeuroAnalyzer.plot_psd(obj::NeuroAnalyzer.NEURO, c::Union{Symbol, AbstractArray}; ep::Int64, c_idx::Union{Int64, Vector{Int64}, <:AbstractRange}=0, norm::Bool=true, method::Symbol=:welch, nt::Int64=7, frq_lim::Tuple{Real, Real}=(0, sr(obj) ÷ 2), ncyc::Union{Int64, Tuple{Int64, Int64}}=32, ref::Symbol=:abs, ax::Symbol=:linlin, xlabel::String="default", ylabel::String="default", zlabel::String="default", title::String="default", mono::Bool=false, type::Symbol=:normal, units::String="", kwargs...)
NeuroAnalyzer.plot_save(p::Union{Plots.Plot{Plots.GRBackend}, GLMakie.Figure}; file_name::String)
NeuroAnalyzer.plot_signal(t::Union{AbstractVector, AbstractRange}, s::Union{AbstractVector, AbstractArray}; clabels::Vector{String}=[""], xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, scale::Bool=true, units::String="", kwargs...)
NeuroAnalyzer.plot_signal(t::Union{AbstractVector, AbstractRange}, s::Union{AbstractVector, AbstractArray}, bad::Vector{Bool}; clabels::Vector{String}=[""], xlabel::String="", ylabel::String="", title::String="", scale::Bool=true, units::String="", kwargs...)
NeuroAnalyzer.plot_signal_avg(t::Union{AbstractVector, AbstractRange}, s::AbstractArray; xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, scale::Bool=true, units::String="", norm::Bool=false, kwargs...)
NeuroAnalyzer.plot_signal_butterfly(t::Union{AbstractVector, AbstractRange}, s::AbstractArray; clabels::Vector{String}=[""], xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, scale::Bool=true, units::String="", norm::Bool=false, kwargs...)
NeuroAnalyzer.plot(obj::NeuroAnalyzer.NEURO; ep::Union{Int64, AbstractRange}=0, ch::Union{Int64, Vector{Int64}, <:AbstractRange}=_c(channel_n(obj)), seg::Tuple{Int64, Int64}=(1, 10*sr(obj)), xlabel::String="default", ylabel::String="default", title::String="default", mono::Bool=false, emarkers::Bool=true, markers::Bool=true, scale::Bool=true, units::String="", type::Symbol=:normal, norm::Bool=false, bad::Union{Bool, Matrix{Bool}}=false, kwargs...)
NeuroAnalyzer.NeuroAnalyzer.plot(obj::NeuroAnalyzer.NEURO, c::Union{Symbol, AbstractArray}; ep::Union{Int64, AbstractRange}=0, c_idx::Union{Int64, Vector{Int64}, <:AbstractRange}=0, seg::Tuple{Int64, Int64}=(1, 10*sr(obj)), xlabel::String="default", ylabel::String="default", title::String="default", mono::Bool=false, emarkers::Bool=true, markers::Bool=true, scale::Bool=true, units::String="a.u.", type::Symbol=:normal, norm::Bool=false, kwargs...)
NeuroAnalyzer.plot_spectrogram(st::Vector{Float64}, sf::Vector{Float64}, sp::Array{Float64, 2}; norm::Bool=true, frq_lim::Tuple{Real, Real}=(0, 0), xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, units::String="", kwargs...)
NeuroAnalyzer.plot_spectrogram(sch::Vector{String}, sf::Vector{Float64}, sp::Array{Float64, 2}; norm::Bool=true, frq_lim::Tuple{Real, Real}=(0, 0), xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, units::String="", kwargs...)
NeuroAnalyzer.plot_spectrogram(obj::NeuroAnalyzer.NEURO; ep::Union{Int64, AbstractRange}, ch::Union{Int64, Vector{Int64}, <:AbstractRange}, norm::Bool=true, method::Symbol=:standard, nt::Int64=7, frq_lim::Tuple{Real, Real}=(0, sr(obj) ÷ 2), ncyc::Union{Int64, Tuple{Int64, Int64}}=32, xlabel::String="default", ylabel::String="default", title::String="default", mono::Bool=false, markers::Bool=true, kwargs...)
NeuroAnalyzer.plot_spectrogram(obj::NeuroAnalyzer.NEURO, c::Union{Symbol, AbstractArray}; ep::Union{Int64, AbstractRange}=0, c_idx::Union{Int64, Vector{Int64}, <:AbstractRange}, norm::Bool=true, method::Symbol=:standard, nt::Int64=7, frq_lim::Tuple{Real, Real}=(0, sr(obj) ÷ 2), ncyc::Union{Int64, Tuple{Int64, Int64}}=32, xlabel::String="default", ylabel::String="default", title::String="default", mono::Bool=false, markers::Bool=true, units::String="", kwargs...)
NeuroAnalyzer.plot_topo(s::Vector{<:Real}; ch::Union{Int64, Vector{Int64}, <:AbstractRange}, locs::DataFrame, cb::Bool=true, cb_label::String="[A.U.]", title::String="default", mono::Bool=false, imethod::Symbol=:sh, nmethod::Symbol=:minmax, plot_contours::Bool=true, plot_electrodes::Bool=true, plot_size::Int64=800, head_labels::Bool=false, head_details::Bool=true, kwargs...)
NeuroAnalyzer.plot_topo(obj::NeuroAnalyzer.NEURO; ep::Union{Int64, AbstractRange}=0, ch::Union{Vector{Int64}, AbstractRange}=signal_channels(obj), seg::Tuple{Int64, Int64}=(1, 10*sr(obj)), title::String="default", mono::Bool=false, cb::Bool=true, cb_label::String="default", amethod::Symbol=:mean, imethod::Symbol=:sh, nmethod::Symbol=:minmax, plot_contours::Bool=true, plot_electrodes::Bool=true, plot_size::Int64=800, head_labels::Bool=false, head_details::Bool=true, kwargs...)
NeuroAnalyzer.plot_topo(obj::NeuroAnalyzer.NEURO, c::Union{Symbol, AbstractArray}; ep::Union{Int64, AbstractRange}=0, c_idx::Union{Int64, Vector{Int64}, <:AbstractRange}=0, seg::Tuple{Int64, Int64}=(1, 10*sr(obj)), title::String="default", mono::Bool=false, cb::Bool=true, cb_label::String="default", amethod::Symbol=:mean, imethod::Symbol=:sh, nmethod::Symbol=:minmax, plot_contours::Bool=true, plot_electrodes::Bool=true, plot_size::Int64=800, head_labels::Bool=false, head_details::Bool=true, kwargs...)
NeuroAnalyzer.plot_matrix(m::Array{<:Real, 2}; xlabels::Vector{String}, ylabels::Vector{String}, xlabel::String="", ylabel::String="", title::String="", cb_title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_covmatrix(m::AbstractVector, lags::AbstractVector; xlabel::String="lag [ms]", ylabel::String="", title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_histogram(s::AbstractVector; type::Symbol=:hist, bins::Union{Int64, Symbol, AbstractVector}=(length(s) ÷ 10), label::String="", xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_bar(s::AbstractVector; xlabels::Vector{String}, xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_line(s::AbstractVector; xlabels::Vector{String}, xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_line(s::AbstractArray; rlabels::Vector{String}, xlabels::Vector{String}, xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_box(s::AbstractArray; glabels::Vector{String}, xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_violin(s::AbstractArray; glabels::Vector{String}, xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_dots(signal::Vector{Vector{Float64}}; glabels::Vector{String}, xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_paired(signal::Vector{Vector{Float64}}; glabels::Vector{String}, xlabel::String="", ylabel::String="", title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_polar(s::Union{AbstractVector, AbstractArray}; m::Tuple{Real, Real}=(0, 0), title::String="", mono::Bool=false, kwargs...)
NeuroAnalyzer.plot_weights(locs::DataFrame; ch::Union{Int64, Vector{Int64}, <:AbstractRange}, weights::Vector{<:Real}=[], channel_labels::Bool=true, head_labels::Bool=true, mono::Bool=false, head_details::Bool=true, plot_size::Int64=400)
NeuroAnalyzer.plot_weights(obj::NeuroAnalyzer.NEURO; ch::Union{Int64, Vector{Int64}, <:AbstractRange}=signal_channels(obj), weights::Vector{<:Real}, channel_labels::Bool=true, head_labels::Bool=false, mono::Bool=false, head_details::Bool=true, plot_size::Int64=800, title::String="", kwargs...)
```

## Statistics

```@docs
NeuroAnalyzer.cmp_test(s1::AbstractVector, s2::AbstractVector; paired::Bool, alpha::Float64=0.05, type::Symbol=:auto, exact::Bool=false, nperm::Int64=1000)
NeuroAnalyzer.cor_test(s1::AbstractVector, s2::AbstractVector)
NeuroAnalyzer.dprime(p1::Real, p2::Real)
NeuroAnalyzer.effsize(x1::AbstractVector, x2::AbstractVector)
NeuroAnalyzer.hildebrand_rule(x::AbstractVector)
NeuroAnalyzer.jaccard_similarity(x::AbstractVector, y::AbstractVector)
NeuroAnalyzer.linreg(x::AbstractVector, y::AbstractVector)
NeuroAnalyzer.infcrit(m::T) where {T<:StatsModels.TableRegressionModel}
NeuroAnalyzer.meang(x::AbstractVector)
NeuroAnalyzer.meanh(x::AbstractVector)
NeuroAnalyzer.meanw(x::AbstractVector, w::AbstractVector)
NeuroAnalyzer.z_score(x::AbstractVector)
NeuroAnalyzer.k_categories(n::Int64)
NeuroAnalyzer.se(x::AbstractVector)
NeuroAnalyzer.rng(x::AbstractVector)
NeuroAnalyzer.moe(n::Int64)
NeuroAnalyzer.cvar(se::Real, s::Real)
NeuroAnalyzer.effsize(p1::Float64, p2::Float64)
NeuroAnalyzer.binom_prob(p::Float64, r::Int64, n::Int64)
NeuroAnalyzer.binom_stat(p::Float64, n::Int64)
NeuroAnalyzer.cvar_mean(x::AbstractVector)
NeuroAnalyzer.cvar_median(x::AbstractVector)
NeuroAnalyzer.mcc(tp::Int64, tn::Int64, fp::Int64, fn::Int64)
NeuroAnalyzer.norminv(x::Real)
NeuroAnalyzer.outlier_detect(x::AbstractVector; method::Symbol=:iqr)
NeuroAnalyzer.grubbs(x::AbstractVector; alpha::Float64=0.95, t::Int64=0)
NeuroAnalyzer.pred_int(n::Int64)
NeuroAnalyzer.prank(x::AbstractVector)
NeuroAnalyzer.dranks(x::AbstractArray, nbins::Int64=round(Int64, 1 + log2(length(x))))
NeuroAnalyzer.res_norm(x::AbstractVector, g::Vector{Int64}=repeat([1], length(x)))
NeuroAnalyzer.seg_mean(seg::AbstractArray)
NeuroAnalyzer.seg_mean(seg1::AbstractArray, seg2::AbstractArray)
NeuroAnalyzer.sem_diff(x::AbstractVector, y::AbstractVector)
```

## Study

```@docs
NeuroAnalyzer.create_study(obj::Vector{NeuroAnalyzer.NEURO}, group::Vector{Symbol})
NeuroAnalyzer.obj_n(study::NeuroAnalyzer.STUDY)
NeuroAnalyzer.channel_n(study::NeuroAnalyzer.STUDY)
NeuroAnalyzer.epoch_n(study::NeuroAnalyzer.STUDY)
NeuroAnalyzer.epoch_len(study::NeuroAnalyzer.STUDY)
NeuroAnalyzer.sr(study::NeuroAnalyzer.STUDY)
```

## NIBS

```@docs
NeuroAnalyzer.ect_charge(; pw::Real, pint::Real, pf::Real, duration::Real)
NeuroAnalyzer.tes_dose(;current::Real, pad_area::Real, duration::Int64)
NeuroAnalyzer.tes_protocol(;type::Symbol, hd::Bool, current::Real, frequency::Real=0, anode_size::Tuple{Int64, Int64}, cathode_size::Tuple{Int64, Int64}, anode_loc::Symbol, cathode_loc::Symbol, duration::Real, ramp_in::Real, ramp_out::Real, sham::Bool)
```
